@@ -1,6 +1,6 @@
 /*
-** oidentd - ojnk ident daemon
-** Copyright (C) 1998,1999,2000 Ryan McCabe <odin@numb.org>
+** oidentd_masq.h - oidentd IP masquerading handler.
+** Copyright (C) 1998-2001 Ryan McCabe <odin@numb.org>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License, version 2,
@@ -10,12 +10,12 @@
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
-** 
+**
 ** You should have received a copy of the GNU General Public License
 ** along with this program; if not, write to the Free Software
 ** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 **
-** $Id: oidentd_masq.h,v 1.1 2000/08/22 01:43:50 odin Exp $
+** $Id: oidentd_masq.h,v 1.8 2001/09/27 20:41:45 odin Exp $
 */
 
 #ifndef __OIDENTD_MASQ_H
@@ -23,11 +23,24 @@
 
 #ifdef MASQ_SUPPORT
 
-#include <netinet/in.h>
+int find_masq_entry(struct sockaddr_storage *host,
+					char *user,
+					size_t user_len,
+					char *os,
+					size_t os_len);
 
-int find_entry(u_long host, u_char *user, size_t ursz, u_char *os, size_t osz);
-int fwd_request(int sock, int rport, int lport, int mport, const struct in_addr *mrelay);
+int fwd_request(int sock,
+				in_port_t fport,
+				in_port_t lport,
+				in_port_t mport,
+				struct sockaddr_storage *mrelay);
 
 #endif
 
+int masq(	int sock,
+			in_port_t lport,
+			in_port_t fport,
+			struct sockaddr_storage *laddr,
+			struct sockaddr_storage *faddr);
+
 #endif
